﻿using System;
using System.Drawing;

using Foundation;
using UIKit;
using Syncfusion.SfChart.iOS;
using CoreGraphics;

namespace ChartSample
{
	public partial class ChartSampleViewController : UIViewController
	{
		static bool UserInterfaceIdiomIsPhone
		{
			get { return UIDevice.CurrentDevice.UserInterfaceIdiom == UIUserInterfaceIdiom.Phone; }
		}

		public ChartSampleViewController(IntPtr handle) : base(handle)
		{

		}

		public override void DidReceiveMemoryWarning()
		{

			base.DidReceiveMemoryWarning();
		}

		SFChart chart;
		public override void ViewDidLoad()
		{
			base.ViewDidLoad();

			chart = new SFChart();
			chart.Frame = this.View.Frame;
			chart.Title.Text = new NSString("Weather Analysis");
			chart.EdgeInsets = new UIEdgeInsets(20, 10, 10, 10);

			SFCategoryAxis primaryAxis = new SFCategoryAxis();
			primaryAxis.Title.Text = new NSString("Month");
			chart.PrimaryAxis = primaryAxis;

			SFNumericalAxis secondaryAxis = new SFNumericalAxis();
			primaryAxis.Title.Text = new NSString("Temperature");
			chart.SecondaryAxis = secondaryAxis;

			ChartDataModel dataModel = new ChartDataModel();
			chart.DataSource = dataModel as SFChartDataSource;
			chart.Delegate = new ChartDelegate();

			chart.Legend.Visible = true;

			this.View.AddSubview(chart);
		}

	}

	public class ChartDelegate : SFChartDelegate
	{
		public override UIView ViewForDataMarkerLabel(SFChart chart, NSString label, nint index, SFSeries series)
		{

			UILabel datamarkerLabel = new UILabel();
			//datamarkerLabel.BackgroundColor = UIColor.Green;
			datamarkerLabel.Layer.BorderColor = UIColor.Purple.CGColor;
			datamarkerLabel.Layer.BorderWidth = 2.0f;
			datamarkerLabel.Layer.CornerRadius = 10;
			datamarkerLabel.TextAlignment = UITextAlignment.Center;
			var labelFrame = datamarkerLabel.Frame;
			labelFrame.Size = new SizeF(35, 30);
			datamarkerLabel.Frame = labelFrame;
			datamarkerLabel.Text = label;
			return datamarkerLabel;
		}
	}

	public class ChartDataModel : SFChartDataSource
	{
		NSMutableArray dataPoints;

		public ChartDataModel()
		{
			dataPoints = new NSMutableArray();
			dataPoints.Add(new SFChartDataPoint(NSObject.FromObject("Jan"), NSObject.FromObject(42)));
			dataPoints.Add(new SFChartDataPoint(NSObject.FromObject("Feb"), NSObject.FromObject(48)));
			dataPoints.Add(new SFChartDataPoint(NSObject.FromObject("Mar"), NSObject.FromObject(56)));
			dataPoints.Add(new SFChartDataPoint(NSObject.FromObject("Apr"), NSObject.FromObject(64)));
			dataPoints.Add(new SFChartDataPoint(NSObject.FromObject("May"), NSObject.FromObject(75)));
			dataPoints.Add(new SFChartDataPoint(NSObject.FromObject("Jun"), NSObject.FromObject(83)));
			dataPoints.Add(new SFChartDataPoint(NSObject.FromObject("Jul"), NSObject.FromObject(87)));
			dataPoints.Add(new SFChartDataPoint(NSObject.FromObject("Aug"), NSObject.FromObject(84)));
			dataPoints.Add(new SFChartDataPoint(NSObject.FromObject("Sep"), NSObject.FromObject(78)));
			dataPoints.Add(new SFChartDataPoint(NSObject.FromObject("Oct"), NSObject.FromObject(67)));
			dataPoints.Add(new SFChartDataPoint(NSObject.FromObject("Nov"), NSObject.FromObject(55)));
			dataPoints.Add(new SFChartDataPoint(NSObject.FromObject("Dec"), NSObject.FromObject(45)));
		}

		public override nint NumberOfSeriesInChart(SFChart chart)
		{
			return 1;
		}

		public override SFSeries GetSeries(SFChart chart, nint index)
		{
			SFLineSeries series = new SFLineSeries();
			series.DataMarker.ShowLabel = true;
			return series;
		}

		public override SFChartDataPoint GetDataPoint(SFChart chart, nint index, nint seriesIndex)
		{
			return dataPoints.GetItem<SFChartDataPoint>((nuint)index);

		}

		public override nint GetNumberOfDataPoints(SFChart chart, nint index)
		{
			return (int)dataPoints.Count;
		}
	}
}

